@@ -1,4 +1,3 @@
-/* $Id: terminal-app.c 30351 2009-07-19 15:31:07Z nick $ */
 /*-
  * Copyright (c) 2004-2008 os-cillation e.K.
  *
@@ -48,6 +47,7 @@
 
 static void               terminal_app_finalize                 (GObject            *object);
 static void               terminal_app_update_accels            (TerminalApp        *app);
+static void               terminal_app_update_mnemonics         (TerminalApp        *app);
 static GtkWidget         *terminal_app_create_window            (TerminalApp        *app,
                                                                  gboolean            fullscreen,
                                                                  TerminalVisibility  menubar,
@@ -66,6 +66,8 @@ static void               terminal_app_window_destroyed         (GtkWidget
 static void               terminal_app_save_yourself            (ExoXsessionClient  *client,
                                                                  TerminalApp        *app);
 static GdkScreen         *terminal_app_find_screen              (const gchar        *display_name);
+static void               terminal_app_open_window              (TerminalApp        *app,
+                                                                 TerminalWindowAttr *attr);
 
 
 
@@ -118,6 +120,8 @@ terminal_app_init (TerminalApp *app)
   app->preferences = terminal_preferences_get ();
   g_signal_connect_swapped (G_OBJECT (app->preferences), "notify::shortcuts-no-menukey",
                             G_CALLBACK (terminal_app_update_accels), app);
+  g_signal_connect_swapped (G_OBJECT (app->preferences), "notify::shortcuts-no-mnemonics",
+                            G_CALLBACK (terminal_app_update_mnemonics), app);
 
   /* remember the original menu bar accel */
   g_object_get (G_OBJECT (gtk_settings_get_default ()),
@@ -125,6 +129,7 @@ terminal_app_init (TerminalApp *app)
                 NULL);
 
   terminal_app_update_accels (app);
+  terminal_app_update_mnemonics (app);
 
   /* connect the accel map */
   app->accel_map = g_object_new (TERMINAL_TYPE_ACCEL_MAP, NULL);
@@ -146,9 +151,8 @@ terminal_app_finalize (GObject *object)
     }
   g_slist_free (app->windows);
 
-  g_signal_handlers_disconnect_by_func (G_OBJECT (app->preferences),
-                                        G_CALLBACK (terminal_app_update_accels),
-                                        app);
+  g_signal_handlers_disconnect_by_func (G_OBJECT (app->preferences), G_CALLBACK (terminal_app_update_accels), app);
+  g_signal_handlers_disconnect_by_func (G_OBJECT (app->preferences), G_CALLBACK (terminal_app_update_mnemonics), app);
   g_object_unref (G_OBJECT (app->preferences));
 
   if (app->initial_menu_bar_accel != NULL)
@@ -186,6 +190,21 @@ terminal_app_update_accels (TerminalApp *app)
 
 
 
+static void
+terminal_app_update_mnemonics (TerminalApp *app)
+{
+  gboolean no_mnemonics;
+
+  g_object_get (G_OBJECT (app->preferences),
+                "shortcuts-no-mnemonics", &no_mnemonics,
+                NULL);
+  g_object_set (G_OBJECT (gtk_settings_get_default ()),
+                "gtk-enable-mnemonics", !no_mnemonics,
+                NULL);
+}
+
+
+
 static GtkWidget*
 terminal_app_create_window (TerminalApp       *app,
                             gboolean           fullscreen,
@@ -422,45 +441,9 @@ terminal_app_find_screen (const gchar *display_name)
 
 
 
-/**
- * terminal_app_process:
- * @app
- * @argv
- * @argc
- * @error
- *
- * Return value:
- **/
-gboolean
-terminal_app_process (TerminalApp  *app,
-                      gchar       **argv,
-                      gint          argc,
-                      GError      **error)
-{
-  GSList *attrs, *lp;
-
-  if (!terminal_options_parse (argc, argv, &attrs, NULL, error))
-    return FALSE;
-
-  for (lp = attrs; lp != NULL; lp = lp->next)
-    terminal_app_open_window (app, lp->data);
-
-  g_slist_foreach (attrs, (GFunc) terminal_window_attr_free, NULL);
-  g_slist_free (attrs);
-
-  return TRUE;
-}
-
-
-
-/**
- * terminal_app_open_window:
- * @app   : A #TerminalApp object.
- * @attr  : The attributes for the new window.
- **/
-void
-terminal_app_open_window (TerminalApp         *app,
-                          TerminalWindowAttr  *attr)
+static void
+terminal_app_open_window (TerminalApp        *app,
+                          TerminalWindowAttr *attr)
 {
   TerminalTabAttr *tab_attr;
   GdkDisplay      *display;
@@ -552,3 +535,37 @@ terminal_app_open_window (TerminalApp         *app,
                         G_CALLBACK (terminal_app_save_yourself), app);
     }
 }
+
+
+
+/**
+ * terminal_app_process:
+ * @app
+ * @argv
+ * @argc
+ * @error
+ *
+ * Return value:
+ **/
+gboolean
+terminal_app_process (TerminalApp  *app,
+                      gchar       **argv,
+                      gint          argc,
+                      GError      **error)
+{
+  GSList *attrs, *lp;
+
+  attrs = terminal_window_attr_parse (argc, argv, error);
+  if (G_UNLIKELY (attrs == NULL))
+    return FALSE;
+
+  for (lp = attrs; lp != NULL; lp = lp->next)
+    {
+      terminal_app_open_window (app, lp->data);
+      terminal_window_attr_free (lp->data);
+    }
+
+  g_slist_free (attrs);
+
+  return TRUE;
+}
