@@ -153,6 +153,8 @@ static void            terminal_window_action_paste                  (GtkAction
                                                                       TerminalWindow         *window);
 static void            terminal_window_action_paste_selection        (GtkAction              *action,
                                                                       TerminalWindow         *window);
+static void            terminal_window_action_select_all             (GtkAction              *action,
+                                                                      TerminalWindow         *window);
 static void            terminal_window_action_edit_toolbars          (GtkAction              *action,
                                                                       TerminalWindow         *window);
 static void            terminal_window_action_prefs                  (GtkAction              *action,
@@ -224,6 +226,7 @@ static const GtkActionEntry action_entries[] =
     { "copy", GTK_STOCK_COPY, N_ ("_Copy"), NULL, N_ ("Copy to clipboard"), G_CALLBACK (terminal_window_action_copy), },
     { "paste", GTK_STOCK_PASTE, N_ ("_Paste"), NULL, N_ ("Paste from clipboard"), G_CALLBACK (terminal_window_action_paste), },
     { "paste-selection", NULL, N_ ("Paste _Selection"), NULL, N_ ("Paste from primary selection"), G_CALLBACK (terminal_window_action_paste_selection), },
+    { "select-all", GTK_STOCK_SELECT_ALL, N_ ("Select _All"), NULL, N_ ("Select all text in the terminal"), G_CALLBACK (terminal_window_action_select_all), },
     { "edit-toolbars", NULL, N_ ("_Toolbars..."), NULL, N_ ("Customize the toolbars"), G_CALLBACK (terminal_window_action_edit_toolbars), },
     { "preferences", GTK_STOCK_PREFERENCES, N_ ("Pr_eferences..."), NULL, N_ ("Open the Terminal preferences dialog"), G_CALLBACK (terminal_window_action_prefs), },
   { "view-menu", NULL, N_ ("_View"), NULL, NULL, NULL, },
@@ -748,6 +751,7 @@ terminal_window_rebuild_gomenu (TerminalWindow *window)
 
       /* create action */
       radio_action = gtk_radio_action_new (name, NULL, NULL, NULL, n);
+      gtk_action_set_sensitive (GTK_ACTION (radio_action), npages > 1);
       exo_binding_new (G_OBJECT (page), "title", G_OBJECT (radio_action), "label");
       gtk_radio_action_set_group (radio_action, group);
       group = gtk_radio_action_get_group (radio_action);
@@ -1316,6 +1320,16 @@ terminal_window_action_paste_selection (GtkAction      *action,
 
 
 
+static void
+terminal_window_action_select_all (GtkAction      *action,
+                                   TerminalWindow *window)
+{
+  if (G_LIKELY (window->active != NULL))
+    terminal_screen_select_all (window->active);
+}
+
+
+
 static void
 terminal_window_action_edit_toolbars (GtkAction       *action,
                                       TerminalWindow  *window)
